summaryrefslogtreecommitdiff
path: root/macosx/Plugin.c
diff options
context:
space:
mode:
authorSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
committerSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
commit5f868fa161d5827e45a060a0b17b44a997625315 (patch)
tree1694ae3dfcb0189abdf098edbf6dae0bf2a18e4d /macosx/Plugin.c
parentc7eb23ccf1813fb4ca47c309c40baff308151237 (diff)
downloadpcsxr-5f868fa161d5827e45a060a0b17b44a997625315.tar.gz
Rebranding.
git-svn-id: https://pcsxr.svn.codeplex.com/svn/pcsxr@67621 e17a0e51-4ae3-4d35-97c3-1a29b211df97
Diffstat (limited to 'macosx/Plugin.c')
-rw-r--r--macosx/Plugin.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/macosx/Plugin.c b/macosx/Plugin.c
index 73769a7f..5bcf7229 100644
--- a/macosx/Plugin.c
+++ b/macosx/Plugin.c
@@ -1,4 +1,4 @@
/* Pcsx - Pc Psx Emulator
* Copyright (C) 1999-2002 Pcsx Team
*
* This program is free software; you can redistribute it and/or modify
@@ -78,7 +78,7 @@ int _OpenPlugins() {
ret = SPU_open();
if (ret < 0) { SysMessage(_("Error Opening SPU Plugin")); return -1; }
SPU_registerCallback(SPUirq);
- ret = GPU_open(&gpuDisp, "PCSX", NULL);
+ ret = GPU_open(&gpuDisp, "PCSXR", NULL);
if (ret < 0) { SysMessage(_("Error Opening GPU Plugin")); return -1; }
GPU_registerCallback(GPUbusy);
ret = PAD1_open(&gpuDisp);
@@ -1,4 +1,4 @@
-/* Pcsx - Pc Psx Emulator
+/* Pcsxr - Pc Psx Emulator
* Copyright (C) 1999-2002 Pcsx Team
*